@@ -287,9 +287,10 @@ class JobCLI(click.MultiCommand):
 	@click.command()
 	@click.argument('job')
 	@click.option('--replicas', default='1', type=int)
+	@click.option('--detach', is_flag = True, default = False)
 	@click.option('--port', '-p', required = False, default = [], multiple = True, type=click.Tuple([str, str]) )	
 	@click.option('--env', '-e', required = False, default = [], multiple = True, type=click.Tuple([str, str]) )
-	def start(job, replicas, port, env):
+	def start(job, replicas, detach, port, env):
 		"""Start an existing job using the specified number of worker replicas."""
 
 		print(f"Checking for the latest version...", end='')
@@ -297,7 +298,9 @@ class JobCLI(click.MultiCommand):
 		print('done')
 
 		env = dict({ "LAAI_JOB": job,
-					 "LAAI_JOB_REPLICAS": replicas},
+					 "LAAI_JOB_REPLICAS": replicas,
+					 "LAAI_JOB_CFG_DETACH": 1 if detach else 0,
+					 },
 					 **{"LAAI_JOB_ARG_" + k : v for k, v in env},
 					 **{"LAAI_JOB_PORT_" + k : v for k, v in port})
 
@@ -309,9 +312,10 @@ class JobCLI(click.MultiCommand):
 			auto_remove = True,
 			detach = True)
 
-		logs = container.attach(stream = True, logs = True)
-		for s in logs:
-			print(s.decode('utf-8').strip())	
+		if not detach:
+			logs = container.attach(stream = True, logs = True)
+			for s in logs:
+				print(s.decode('utf-8').strip())	
 
 	@click.command()	
 	def ls():		
@@ -398,13 +402,6 @@ class HpoCLI(click.MultiCommand):
 	@click.option('--parent-run', is_flag = True, required = False)
 	@click.option('--active-run-params', is_flag = True, required = False)
 	@click.option('--hp-set-id', required = False)
-	# @click.option('--parent-run-id', default = None, required = False)
-	# @click.option('--num-runs', required = False, default = 1, show_default=True)
-	# @click.option('--seed', required = False, default = 42, show_default=True)
-	# @click.option('--service-prefix', required = False, default = 'laai.hpo.services', show_default=True)
-	# @click.option('--service-name', required = False, default = 'BaseMLFlowService', show_default=True)
-	# @click.option('--port', '-p', required = False, default = [], multiple = True, type=click.Tuple([str, str]) )	
-	# @click.option('--env', '-e', required = False, default = [], multiple = True, type=click.Tuple([str, str]) )
 	def inspect(name, parent_run, active_run_params, hp_set_id):
 		from laai.hpo.mlflow_utils import get_client, get_parent_run, \
 			get_active_child_run, get_active_run_params, \
@@ -545,72 +542,4 @@ class HpoCLI(click.MultiCommand):
 @cli.command(cls=HpoCLI)
 def hpo():
 	"""Manage hyperparameter optimization."""
-	pass
-
-
-# # @click.group(invoke_without_command=False)
-# # @click.pass_context
-# # def dojo_cmds(ctx):
-# # 	pass
-# # 	# print("dojo")
-# # 	# if ctx.invoked_subcommand is None:
-# # 	# 	click.echo('I was invoked without subcommand')
-# # 	# else:
-# # 	# 	click.echo('I am about to invoke %s' % ctx.invoked_subcommand)
-
-# # @dojo_cmds.command()	
-# # @click.pass_context
-# # def dojo_ls(ctx):
-# # 	print("dojo ls")
-# # 	if ctx.invoked_subcommand is None:
-# # 		click.echo('I was invoked without subcommand')
-# # 	else:
-# # 		click.echo('I am about to invoke %s' % ctx.invoked_subcommand)
-
-
-# # @main.command("dojo")
-# # @click.option('ls', required=False)
-# # @click.pass_context
-# # def dojo_main(ctx):
-# # 	print("dojo main")
-# # 	# cli = click.CommandCollection(sources=[dojo_cmds])
-# # 	# cli(ctx)
-
-
-
-# # 	# pass
-
-
-# # # if __name__ == '__main__':
-# # # 	cli = click.CommandCollection(sources=[dojo, run])
-# # # 	cli()
-
-
-# # @click.group(chain=True, invoke_without_command=True)
-# # @click.pass_context
-# # def dojo_cmds(ctx):
-# #     if ctx.invoked_subcommand is None:
-# #         click.echo('I was invoked without subcommand')
-# #     else:
-# #         click.echo('I am about to invoke %s' % ctx.invoked_subcommand)
-
-# # @dojo_cmds.command("dojo")
-# # def dojo():
-# # 	print("dojo")
-
-# # @dojo_cmds.command("dojo ls")
-# # def dojo():
-# # 	print("dojo")
-
-# # @dojo_cmds.command()
-# # def ls():
-# # 	print("ls")
-
-# # @click.group()
-# # def run():
-# # 	pass
-
-# # @run.command()
-# # def run_ls():
-# # 	print("run ls")
-
+	pass
\ No newline at end of file
